@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # SPDX-License-Identifier: Apache-2.0
 # Copyright 2018-2021 Michael R. Crusoe
-"""CWL Expression refactoring tool for CWL v1.2 ."""
+"""CWL Expression refactoring tool for CWL v1.1 ."""
 import copy
 import hashlib
 from collections.abc import Mapping
@@ -22,8 +22,8 @@ from ruamel import yaml
 from schema_salad.sourceline import SourceLine
 from schema_salad.utils import json_dumps
 
-import cwl_utils.parser.cwl_v1_2 as cwl
-import cwl_utils.parser.cwl_v1_2_utils as utils
+import cwl_utils.parser.cwl_v1_1 as cwl
+import cwl_utils.parser.cwl_v1_1_utils as utils
 from cwl_utils.errors import JavascriptException, WorkflowException
 from cwl_utils.expression import do_eval, interpolate
 from cwl_utils.types import CWLObjectType, CWLOutputType
@@ -183,14 +183,14 @@ var runtime=$(runtime);"""
         contents += "\n" + "\n".join(expressionLib)
     contents += (
         """
-    var ret = function(){"""
+var ret = function(){"""
         + escape_expression_field(etool.expression.strip()[2:-1])
         + """}();
 process.stdout.write(JSON.stringify(ret));"""
     )
     listing = [cwl.Dirent(entryname="expression.js", entry=contents, writable=None)]
     iwdr = cwl.InitialWorkDirRequirement(listing)
-    containerReq = cwl.DockerRequirement(dockerPull="node:slim")
+    containerReq = cwl.DockerRequirement(dockerPull="node:alpine")
     softwareHint = cwl.SoftwareRequirement(
         packages=[cwl.SoftwarePackage(package="nodejs")]
     )
@@ -389,7 +389,7 @@ def generate_etool_from_expr(
         expression += "\n  var self=inputs.self;"
     expression += (
         """
-      return {"result": function(){"""
+  return {"result": function(){"""
         + expr[2:-2]
         + """}()};
  }"""
@@ -601,50 +601,6 @@ TOPLEVEL_FORMAT_EXPR_ERROR = (
     "into separate ExpressionTool/CommandLineTool steps."
 )
 
-PICKVALUE_FIRST_NON_NULL_EXPR = """${
-for (let i = 0; i < self.length; i++) {
-  if (self[i] !== null){
-    return self[i];
-  }
-}
-throw 'pickValue=first_non_null, but no non-null value found: ' + self;
-}
-"""
-
-PICKVALUE_THE_ONLY_NON_NULL_EXPR = """${
-var found = null;
-self.forEach(function(item) {
-  if (item !== null) {
-    if (found !== null) {
-      throw 'pickValue=the_only_non_null, but multiple non-null values found: ' + self;
-    } else {
-      found = item;
-    }
-  }
-})
-if (found !== null) {
-  return found;
-}
-throw 'pickValue=the_only_non_null, but no non-null value found: ' + self;
-}
-"""
-
-PICKVALUE_ALL_NON_NULL_EXPR = """${
-var results = [];
-self.forEach(function(item) {
-  if (item !== null){
-    results.push(item);
-  }
-})
-return results;
-}
-"""
-
-PICKVALUE_ERROR = (
-    "pickValue '{}' is invalid. Should be one of 'first_non_null', "
-    "'the_only_non_null', 'all_non_null'"
-)
-
 
 def process_workflow_inputs_and_outputs(
     workflow: cwl.Workflow, replace_etool: bool
@@ -680,57 +636,6 @@ def process_workflow_inputs_and_outputs(
                                 f"Entry {index},"
                                 + TOPLEVEL_SF_EXPR_ERROR.format(param.id.split("#")[-1])
                             )
-    generated_pickValue_steps = []
-    for index3, param2 in enumerate(workflow.outputs):
-        with SourceLine(workflow.outputs, index3, WorkflowException):
-            if param2.pickValue:
-                if param2.pickValue == "first_non_null":
-                    expression = PICKVALUE_FIRST_NON_NULL_EXPR
-                elif param2.pickValue == "the_only_non_null":
-                    expression = PICKVALUE_THE_ONLY_NON_NULL_EXPR
-                elif param2.pickValue == "all_non_null":
-                    expression = PICKVALUE_ALL_NON_NULL_EXPR
-                else:
-                    raise WorkflowException(PICKVALUE_ERROR.format(param2.pickValue))
-                modified = True
-
-                etool_id = "_pickValue_workflow_step_{}".format(
-                    param2.id.split("#")[-1]
-                )
-                target_type = copy.deepcopy(param2.type)
-                if isinstance(target_type, cwl.OutputArraySchema):
-                    target_type.name = None
-                target = cwl.WorkflowInputParameter(id=None, type=target_type)
-                if not isinstance(param2.outputSource, list):
-                    sources = param2.outputSource.split("#")[-1]
-                else:
-                    sources = [s.split("#")[-1] for s in param2.outputSource]
-                source_type_items = utils.type_for_source(workflow, sources)
-                if isinstance(source_type_items, cwl.ArraySchema):
-                    if isinstance(source_type_items.items, list):
-                        if "null" not in source_type_items.items:
-                            source_type_items.items.append("null")
-                    elif source_type_items.items != "null":
-                        source_type_items.items = ["null", source_type_items.items]
-                elif isinstance(source_type_items, list):
-                    if "null" not in source_type_items:
-                        source_type_items.append("null")
-                elif source_type_items != "null":
-                    source_type_items = ["null", source_type_items]
-                source_type = cwl.CommandInputParameter(type=source_type_items)
-                replace_expr_with_etool(
-                    expression,
-                    etool_id,
-                    workflow,
-                    target,
-                    sources,
-                    replace_etool,
-                    None,
-                    source_type,
-                )
-                param2.outputSource = f"{etool_id}/result"
-                param2.pickValue = None
-                generated_pickValue_steps.append(etool_id)
     return modified
 
 
@@ -747,7 +652,8 @@ def process_workflow_reqs_and_hints(
     """
     # TODO: consolidate the generated etools/cltools into a single "_expression_workflow_reqs" step
     # TODO: support resourceReq.* references to Workflow.inputs?
-    #       ^ By refactoring replace_expr_etool to allow multiple inputs, and connecting all workflow inputs to the generated step
+    #       ^ By refactoring replace_expr_etool to allow multiple inputs,
+    #         and connecting all workflow inputs to the generated step
     modified = False
     inputs = empty_inputs(workflow)
     generated_res_reqs: List[Tuple[str, Union[int, str]]] = []
@@ -932,7 +838,8 @@ def process_workflow_reqs_and_hints(
                                                     raise_type=WorkflowException,
                                                 ).makeError(
                                                     f"Entry {index},"
-                                                    + "Invalid CWL, if 'entry' is a string, then entryName must be specified."
+                                                    + "Invalid CWL, if 'entry' "
+                                                    "is a string, then entryName must be specified."
                                                 )
                                             expr = (
                                                 '${return {"class": "File", "basename": "'
@@ -1074,7 +981,8 @@ def process_level_reqs(
     # - Replace the CWL Expression inplace with a CWL parameter reference
     # - Don't create a new Requirement, nor delete the existing Requirement
     # - the Process is passed to replace_expr_with_etool for later searching for JS expressionLibs
-    # - in addition to adding the input to the step for the ETool/CTool result, add it to the Process.inputs as well
+    # - in addition to adding the input to the step for the ETool/CTool result,
+    #   add it to the Process.inputs as well
     if not process.requirements:
         return False
     modified = False
@@ -1217,7 +1125,7 @@ def process_level_reqs(
                                         entryname = (
                                             entry.entryname
                                             if entryname_expr
-                                            else f'"{entry.entryname}"'
+                                            else f'"{entry.entryname}"'  # noqa: B907
                                         )
                                         new_expression = (
                                             "${var result; var entryname = "
@@ -1811,7 +1719,7 @@ def generate_etool_from_expr2(
         expression += f"\n  var self=inputs.{self_name};"
     expression += (
         """
-      return {"result": function(){"""
+  return {"result": function(){"""
         + expr[2:-2]
         + """}()};
  }"""
@@ -1967,14 +1875,6 @@ def traverse_step(
                 )
                 inp.valueFrom = None
                 inp.source = f"{etool_id}/result"
-    if step.when:
-        expression = get_expression(string=step.when, inputs=inputs, self=None)
-        if expression:
-            modified = True
-            replace_step_when_expr_with_etool(
-                expression, parent, step, original_step_ins, replace_etool
-            )
-
     # TODO: skip or special process for sub workflows?
     process_modified = process_level_reqs(
         original_process,
@@ -2111,70 +2011,6 @@ def replace_step_valueFrom_expr_with_etool(
     )
 
 
-def replace_step_when_expr_with_etool(
-    expr: str,
-    workflow: cwl.Workflow,
-    step: cwl.WorkflowStep,
-    original_step_ins: List[cwl.WorkflowStepInput],
-    replace_etool: bool,
-) -> None:
-    """Replace a WorkflowStep level 'when' expression with a sibling ExpressionTool step."""
-    if not step.id:
-        raise WorkflowException(f"Missing id from {step}.")
-    etool_id = "_when_expression_{}".format(step.id.split("#")[-1])
-    etool_inputs = workflow_step_to_WorkflowInputParameters(
-        original_step_ins, workflow, ""
-    )
-    temp_etool = generate_etool_from_expr2(
-        expr,
-        cwl.WorkflowInputParameter(id=None, type="boolean"),
-        etool_inputs,
-        None,
-        None,
-        [workflow, step],
-    )
-    if replace_etool:
-        processes = [
-            workflow,
-            step,
-        ]  # type: List[Union[cwl.Workflow, cwl.CommandLineTool, cwl.ExpressionTool, cwl.WorkflowStep]]
-        cltool = etool_to_cltool(temp_etool, find_expressionLib(processes))
-        etool = cltool  # type: Union[cwl.ExpressionTool, cwl.CommandLineTool]
-    else:
-        etool = temp_etool
-    wf_step_inputs = copy.deepcopy(original_step_ins)
-    for wf_step_input in wf_step_inputs:
-        if not wf_step_input.id:
-            continue
-        wf_step_input.id = wf_step_input.id.split("/")[-1]
-        if wf_step_input.source:
-            if isinstance(wf_step_input.source, MutableSequence):
-                for index, inp_source in enumerate(wf_step_input.source):
-                    wf_step_input.source[index] = inp_source.split("#")[-1]
-            else:
-                wf_step_input.source = wf_step_input.source.split("#")[-1]
-    wf_step_inputs[:] = [x for x in wf_step_inputs if x.id and not x.id.startswith("_")]
-    scatter = copy.deepcopy(step.scatter)
-    if isinstance(scatter, str):
-        scatter = [scatter]
-    if isinstance(scatter, MutableSequence):
-        for index, entry in enumerate(scatter):
-            scatter[index] = entry.split("/")[-1]
-    scatter = step.scatter
-    workflow.steps.append(
-        cwl.WorkflowStep(
-            id=etool_id,
-            in_=wf_step_inputs,
-            out=[cwl.WorkflowStepOutput("result")],
-            run=etool,
-            scatter=scatter,
-            scatterMethod=step.scatterMethod,
-        )
-    )
-    step.when = "$(inputs._when)"
-    step.in_.append(cwl.WorkflowStepInput(id="_when", source=f"{etool_id}/result"))
-
-
 def traverse_workflow(
     workflow: cwl.Workflow,
     replace_etool: bool,
