@@ -4,7 +4,8 @@ import logging
 import os
 import subprocess  # nosec
 from abc import ABC, abstractmethod
-from typing import List
+from pathlib import Path
+from typing import List, Union
 
 from .singularity import get_version as get_singularity_version
 from .singularity import is_version_2_6 as is_singularity_version_2_6
@@ -15,10 +16,14 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class ImagePuller(ABC):
-    def __init__(self, req: str, save_directory: str) -> None:
+    def __init__(
+        self, req: str, save_directory: Union[str, Path], cmd: str, force_pull: bool
+    ) -> None:
         """Create an ImagePuller."""
         self.req = req
         self.save_directory = save_directory
+        self.cmd = cmd
+        self.force_pull = force_pull
 
     @abstractmethod
     def get_image_name(self) -> str:
@@ -45,7 +50,11 @@ class DockerImagePuller(ImagePuller):
 
     def get_image_name(self) -> str:
         """Get the name of the tarball."""
-        return "".join(self.req.split("/")) + ".tar"
+        name = "".join(self.req.split("/")) + ".tar"
+        # Replace colons with underscores in the name.
+        # See https://github.com/containers/podman/issues/489
+        name = name.replace(":", "_")
+        return name
 
     def generate_udocker_loading_command(self) -> str:
         """Generate the udocker loading command."""
@@ -54,19 +63,20 @@ class DockerImagePuller(ImagePuller):
     def save_docker_image(self) -> None:
         """Download and save the software container image to disk as a docker tarball."""
         _LOGGER.info(f"Pulling {self.req} with Docker...")
-        cmd_pull = ["docker", "pull", self.req]
+        cmd_pull = [self.cmd, "pull", self.req]
         ImagePuller._run_command_pull(cmd_pull)
+        dest = os.path.join(self.save_directory, self.get_image_name())
+        if self.force_pull:
+            os.remove(dest)
         cmd_save = [
-            "docker",
+            self.cmd,
             "save",
             "-o",
-            os.path.join(self.save_directory, self.get_image_name()),
+            dest,
             self.req,
         ]
         subprocess.run(cmd_save, check=True)  # nosec
-        _LOGGER.info(
-            f"Image successfully pulled: {self.save_directory}/{self.get_image_name()}"
-        )
+        _LOGGER.info(f"Image successfully pulled: {dest!r}.")
         print(self.generate_udocker_loading_command())
 
 
@@ -76,10 +86,6 @@ class SingularityImagePuller(ImagePuller):
     CHARS_TO_REPLACE = ["/"]
     NEW_CHAR = "_"
 
-    def __init__(self, req: str, save_directory: str) -> None:
-        """Create a Singularity-based software container image downloader."""
-        super().__init__(req, save_directory)
-
     def get_image_name(self) -> str:
         """Determine the file name appropriate to the installed version of Singularity."""
         image_name = self.req
@@ -96,15 +102,27 @@ class SingularityImagePuller(ImagePuller):
         return f"{image_name}{suffix}"
 
     def save_docker_image(self) -> None:
-        """Pull down the Docker container image in the Singularity image format."""
+        """Pull down the Docker software container image and save it in the Singularity image format."""
+        if (
+            os.path.exists(os.path.join(self.save_directory, self.get_image_name()))
+            and not self.force_pull
+        ):
+            _LOGGER.info(f"Already cached {self.req} with Singularity.")
+            return
         _LOGGER.info(f"Pulling {self.req} with Singularity...")
         cmd_pull = [
-            "singularity",
+            self.cmd,
             "pull",
-            "--name",
-            os.path.join(self.save_directory, self.get_image_name()),
-            f"docker://{self.req}",
         ]
+        if self.force_pull:
+            cmd_pull.append("--force")
+        cmd_pull.extend(
+            [
+                "--name",
+                os.path.join(self.save_directory, self.get_image_name()),
+                f"docker://{self.req}",
+            ]
+        )
         ImagePuller._run_command_pull(cmd_pull)
         _LOGGER.info(
             f"Image successfully pulled: {self.save_directory}/{self.get_image_name()}"
