@@ -4,15 +4,15 @@ import logging
 from collections import namedtuple
 from typing import IO, Any, Dict, List, MutableSequence, Optional, Tuple, Union, cast
 
-from ruamel import yaml
 from schema_salad.exceptions import ValidationException
 from schema_salad.sourceline import SourceLine
 from schema_salad.utils import aslist, json_dumps
 
 import cwl_utils.parser
-import cwl_utils.parser.cwl_v1_1 as cwl
+import cwl_utils.parser.cwl_v1_0 as cwl
 import cwl_utils.parser.utils
 from cwl_utils.errors import WorkflowException
+from cwl_utils.utils import yaml_dumps
 
 CONTENT_LIMIT: int = 64 * 1024
 
@@ -210,7 +210,7 @@ def content_limit_respected_read(f: IO[bytes]) -> str:
 
 
 def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
-    """Convert stdin, stdout and stderr type shortcuts to files."""
+    """Convert stdout and stderr type shortcuts to files."""
     for out in clt.outputs:
         if out.type == "stdout":
             if out.outputBinding is not None:
@@ -238,22 +238,6 @@ def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
                 )
             out.type = "File"
             out.outputBinding = cwl.CommandOutputBinding(glob=clt.stderr)
-    for inp in clt.inputs:
-        if inp.type == "stdin":
-            if inp.inputBinding is not None:
-                raise ValidationException(
-                    "Not allowed to specify unputBinding when using stdin shortcut."
-                )
-            if clt.stdin is not None:
-                raise ValidationException(
-                    "Not allowed to specify stdin path when using stdin type shortcut."
-                )
-            else:
-                clt.stdin = (
-                    "$(inputs.%s.path)"
-                    % cast(str, inp.id).rpartition("#")[2].split("/")[-1]
-                )
-                inp.type = "File"
 
 
 def merge_flatten_type(src: Any) -> Any:
@@ -295,12 +279,12 @@ def type_for_step_output(
     step_run = cwl_utils.parser.utils.load_step(step)
     cwl_utils.parser.utils.convert_stdstreams_to_files(step_run)
     if step_run and step_run.outputs:
-        for output in step_run.outputs:
+        for step_output in step_run.outputs:
             if (
-                output.id.split("#")[-1].split("/")[-1]
+                step_output.id.split("#")[-1].split("/")[-1]
                 == sourcename.split("#")[-1].split("/")[-1]
             ):
-                output_type = output.type
+                output_type = step_output.type
                 if step.scatter is not None:
                     if step.scatterMethod == "nested_crossproduct":
                         for _ in range(len(aslist(step.scatter))):
@@ -313,7 +297,7 @@ def type_for_step_output(
     raise ValidationException(
         "param {} not found in {}.".format(
             sourcename,
-            yaml.main.round_trip_dump(cwl.save(step)),
+            yaml_dumps(cwl.save(step_run)),
         )
     )
 
@@ -373,11 +357,11 @@ def param_for_source_id(
     sourcenames: Union[str, List[str]],
     parent: Optional[cwl.Workflow] = None,
     scatter_context: Optional[List[Optional[Tuple[int, str]]]] = None,
-) -> Union[List[cwl.WorkflowInputParameter], cwl.WorkflowInputParameter]:
+) -> Union[List[cwl.InputParameter], cwl.InputParameter]:
     """Find the process input parameter that matches one of the given sourcenames."""
     if isinstance(sourcenames, str):
         sourcenames = [sourcenames]
-    params: List[cwl.WorkflowInputParameter] = []
+    params: List[cwl.InputParameter] = []
     for sourcename in sourcenames:
         if not isinstance(process, cwl.Workflow):
             for param in process.inputs:
@@ -417,27 +401,26 @@ def param_for_source_id(
                                         ):
                                             params.append(output)
                                             if scatter_context is not None:
-                                                if scatter_context is not None:
-                                                    if isinstance(step.scatter, str):
-                                                        scatter_context.append(
-                                                            (
-                                                                1,
-                                                                step.scatterMethod
-                                                                or "dotproduct",
-                                                            )
+                                                if isinstance(step.scatter, str):
+                                                    scatter_context.append(
+                                                        (
+                                                            1,
+                                                            step.scatterMethod
+                                                            or "dotproduct",
                                                         )
-                                                    elif isinstance(
-                                                        step.scatter, MutableSequence
-                                                    ):
-                                                        scatter_context.append(
-                                                            (
-                                                                len(step.scatter),
-                                                                step.scatterMethod
-                                                                or "dotproduct",
-                                                            )
+                                                    )
+                                                elif isinstance(
+                                                    step.scatter, MutableSequence
+                                                ):
+                                                    scatter_context.append(
+                                                        (
+                                                            len(step.scatter),
+                                                            step.scatterMethod
+                                                            or "dotproduct",
                                                         )
-                                                    else:
-                                                        scatter_context.append(None)
+                                                    )
+                                                else:
+                                                    scatter_context.append(None)
     if len(params) == 1:
         return params[0]
     elif len(params) > 1:
@@ -445,9 +428,7 @@ def param_for_source_id(
     raise WorkflowException(
         "param {} not found in {}\n{}.".format(
             sourcename,
-            yaml.main.round_trip_dump(cwl.save(process)),
-            f" or\n {yaml.main.round_trip_dump(cwl.save(parent))}"
-            if parent is not None
-            else "",
+            yaml_dumps(cwl.save(process)),
+            f" or\n {yaml_dumps(cwl.save(parent))}" if parent is not None else "",
         )
     )
