@@ -34,6 +34,7 @@ from cwl_utils.types import CWLOutputType
 from cwl_utils.utils import singularity_supports_userns
 
 default_timeout = 20
+"""Default number of seconds to wait while running a javascript engine."""
 
 seg_symbol = r"""\w+"""
 seg_single = r"""\['([^']|\\')+'\]"""
@@ -117,7 +118,7 @@ class NodeJSEngine(JSEngine):
                     try:
                         with open(cidfile[0]) as inp_stream:
                             p = subprocess.Popen(  # nosec
-                                ["docker", "kill", inp_stream.read()],
+                                [args[0], "kill", inp_stream.read()],
                                 shell=False,  # nosec
                             )
                             try:
@@ -164,6 +165,13 @@ class NodeJSEngine(JSEngine):
         force_docker_pull: bool = False,
         container_engine: str = "docker",
     ) -> Tuple[int, str, str]:
+        """
+        Run a javascript text.
+
+        :param timeout: Max number of seconds to wait.
+        :returns: A tuple of the return code, stdout, and stderr of the javascript
+                  engine invocation.
+        """
         if not hasattr(self.localdata, "procs"):
             self.localdata.procs = {}
 
@@ -310,6 +318,8 @@ class NodeJSEngine(JSEngine):
                 nodeimg = "docker.io/node:alpine"
                 if container_engine == "singularity":
                     nodeimg = f"docker://{nodeimg}"
+                elif container_engine == "podman":
+                    nodeimg = "docker.io/library/node:alpine"
 
                 if not self.have_node_slim:
                     singularity_cache: Optional[str] = None
@@ -330,6 +340,16 @@ class NodeJSEngine(JSEngine):
                             )
                         if singularityimgs:
                             nodeimg = singularityimgs[0]
+                    elif container_engine == "udocker":
+                        matches = re.search(
+                            re.escape(nodeimg),
+                            subprocess.check_output(  # nosec
+                                [container_engine, "images"],
+                                universal_newlines=True,
+                            ),
+                        )
+                        if matches:
+                            dockerimgs = matches[0]
                     else:
                         raise Exception(
                             f"Unknown container_engine: {container_engine}."
@@ -359,7 +379,10 @@ class NodeJSEngine(JSEngine):
                         )
                     self.have_node_slim = True
                 nodejs_commands = [container_engine]
-                if container_engine != "singularity":
+                if (
+                    container_engine != "singularity"
+                    and "udocker" not in container_engine
+                ):
                     nodejs_commands.extend(
                         [
                             "run",
@@ -371,7 +394,7 @@ class NodeJSEngine(JSEngine):
                             "--rm",
                         ]
                     )
-                else:
+                elif "singularity" in container_engine:
                     nodejs_commands.extend(
                         [
                             "exec",
@@ -381,6 +404,15 @@ class NodeJSEngine(JSEngine):
                             "--userns" if singularity_supports_userns() else "--pid",
                         ]
                     )
+                elif "udocker" in container_engine:
+                    nodejs_commands.extend(
+                        [
+                            "run",
+                            "--device=/dev/stdin",
+                            "--device=/dev/stdout",
+                            "--device=/dev/stderr",
+                        ]
+                    )
                 nodejs_commands.extend(
                     [
                         nodeimg,
