@@ -24,7 +24,7 @@ TEST_v1_0_CWL_REMOTE = (
 )
 TEST_v1_2_CWL = get_data("testdata/workflow_input_format_expr_v1_2.cwl")
 yaml = YAML(typ="rt")
-yaml.preserve_quotes = True  # type: ignore[assignment]
+yaml.preserve_quotes = True
 
 
 def test_cwl_version() -> None:
@@ -111,6 +111,13 @@ def test_get_default_id_from_graph() -> None:
 
 def test_get_default_id_from_graph_without_main() -> None:
     """Test that loading the default id of a CWL document with $graph property and no `#main` id throws an error."""  # noqa: B950
+    uri = Path(get_data("testdata/js-expr-req-wf.cwl")).resolve().as_uri()
     with raises(GraphTargetMissingException):
-        uri = Path(get_data("testdata/js-expr-req-wf.cwl")).resolve().as_uri()
         load_document_by_uri(uri)
+
+
+def test_graph_load_all() -> None:
+    """Test that we can get all object in a $graph file."""
+    uri = Path(get_data("testdata/js-expr-req-wf.cwl")).resolve().as_uri()
+    cwl_objs = load_document_by_uri(uri, load_all=True)
+    assert len(cwl_objs) == 2
